@@ -43,7 +43,6 @@ def review(openai_key, assistant_id, token, repo, branch, message, gh_before, sh
         print(f"Error running cururo: {e}")
         return
     
-    print(note)
     response = extract_message(note)
     if not response:
         print("No response extracted from the note.")
@@ -59,7 +58,7 @@ def review(openai_key, assistant_id, token, repo, branch, message, gh_before, sh
         return
 
     try:
-        git_publisher.publish(response)
+        issue_number, comment_id = git_publisher.publish(response)
         author = git_publisher.user
     except Exception as e:
         print(f"Unexpected error: {e}")
@@ -67,7 +66,7 @@ def review(openai_key, assistant_id, token, repo, branch, message, gh_before, sh
     try:
       web_publisher.publish(web_publisher.sort_data({
           'message': response['message'].get('provided', ''),
-          'suggested': response['message'].get('suggested', ''),
+          'suggested': response['message'].get('generated', ''),
           'adherence': int(response['message']['adherence'].get('score', 0)),
           'vulnerability': int(response['codeVulnerability'].get('score', 0)),
           'singleResponsibility': int(response['codeSOLID']['singleResponsibility'].get('score', 0)),
@@ -75,7 +74,7 @@ def review(openai_key, assistant_id, token, repo, branch, message, gh_before, sh
           'liskovSubstitution': int(response['codeSOLID']['liskovSubstitution'].get('score', 0)),
           'interfaceSegregation': int(response['codeSOLID']['interfaceSegregation'].get('score', 0)),
           'dependencyInversion': int(response['codeSOLID']['dependencyInversion'].get('score', 0)),
-      }, {"user": author, "sha": sha, "repo": repo}))
+      }, {"user": author, "sha": sha, "repo": repo, "branch": branch, "issue": str(issue_number), "comment": str(comment_id)}))
     except Exception as e:
         print(f"Unexpected error: {e}")
 
